@@ -14,7 +14,7 @@ class BuildError(Exception):
 
 
 def handle_build_log_message(msg):
-    msg = json.load(msg)
+    msg = json.loads(msg)
     if msg == ":BUILD_DONE:":
         return True
     elif msg == ":ERROR:":
